mod fan;
mod temperatures;

use fan::hysteresis::Hysteresis;
use fan::pwm::Pwm;
use fan::Fan;

use rppal::pwm::Channel;
use std::thread;
use std::time::Duration;

fn main() {
    let mut temps = temperatures::Temperatures::default();

    let mut fan: Box<dyn Fan> = if true {
        Box::new(Hysteresis::new(52.0, 5.0, 18))
    } else {
        Box::new(Pwm::new(52.0, 42.0, Channel::Pwm0))
    };

    loop {
        temps.update();
        fan.update_temperature(&temps);
        println!(
            "CPU: {:.1}°C, fan is at {:.1}%",
            temps.cpu,
            fan.percentage() * 100_f64
        );

        thread::sleep(Duration::from_secs(5));
    }
}
